/*
 * SPDX-FileCopyrightText: 2024-2025 Bruno Anselme <be.root@gfree.fr>
 *
 * Authors:
 *   Bruno Anselme <be.root@gfree.fr>
 *
 *   SPDX-License-Identifier: GPL-3.0-or-later
 *
 * This file is part of the NoComprendo software.
*/

/**
 * @file      mouseblink.cpp
 * @author    Bruno ANSELME
 * @brief     MouseBlink class definition
 * @details   Mouse animation class for visual cursor location.
 */

#include <QPalette>
#include <QPainter>
#include "blink.h"
#include "misc.h"

MouseBlink::MouseBlink() :
    QWidget(nullptr, Qt::FramelessWindowHint
            | Qt::WindowStaysOnTopHint
            | Qt::X11BypassWindowManagerHint
            | Qt::WindowDoesNotAcceptFocus
            | Qt::SplashScreen)
{
    counter = 0;
    timerBlink  = 0;
    QRectF rscreens = getDesktopRect();
    setGeometry(rscreens.toRect());
    setAttribute(Qt::WA_TranslucentBackground, true);
}

void MouseBlink::start() {
    counter = 255/5;
    show();
    timerBlink  = startTimer(10);
}

void MouseBlink::timerEvent(QTimerEvent *event){
    if (event->timerId() == timerBlink) {
        counter--;
        update();
        if (!counter) {
            killTimer(timerBlink);
            timerBlink  = 0;
            hide();
        }
    }
}

void MouseBlink::paintEvent(QPaintEvent *event) {
    QWidget::paintEvent(event);
    QPainter    painter(this);
    QPen pen;
    pen.setWidth(2);
    pen.setColor(QColor(5*counter, 5*counter, 5*counter));
    painter.setPen(pen);
    painter.drawEllipse(QCursor::pos(), 10*counter, 10*counter);
    painter.drawEllipse(QCursor::pos(),  7*counter,  2*counter);
    painter.drawEllipse(QCursor::pos(),  2*counter,  7*counter);
}
