/*
 * SPDX-FileCopyrightText: 2024-2025 Bruno Anselme <be.root@gfree.fr>
 *
 * Authors:
 *   Bruno Anselme <be.root@gfree.fr>
 *
 *   SPDX-License-Identifier: GPL-3.0-or-later
 *
 * This file is part of the NoComprendo software.
*/

#include "filedownloader.h"

#define READ_BUFFER_SIZE    1048576

FileDownloader::FileDownloader(QUrl url, QString fileName_, QObject *parent) :
    QObject(parent)
  , fileName(fileName_)
  , file(fileName_)
  , opened(false)
{
    opened = file.open(QIODevice::WriteOnly);
    QNetworkRequest request(url);

    reply = m_WebCtrl.get(request);
    reply->setReadBufferSize(READ_BUFFER_SIZE);
    connect(reply, SIGNAL(readyRead()), this, SLOT(writeChunk()));
    connect(reply, SIGNAL(downloadProgress(qint64,qint64)), this, SLOT(showProgress(qint64,qint64)));
    connect(reply, SIGNAL(finished()), this, SLOT(fileDownloaded()));

    progress = new QProgressDialog();
    progress->setWindowModality(Qt::ApplicationModal);
    progress->setWindowTitle(tr("Download"));
    progress->setLabelText(tr("Downloading language model..."));
    progress->setCancelButtonText(tr("Abort download"));
    connect(progress, SIGNAL(canceled()), this, SLOT(cancelDownload()));
}

FileDownloader::~FileDownloader() {
    delete reply;
    delete progress;
}

void FileDownloader::writeChunk() {
    if (opened) {
        file.write(reply->read(reply->bytesAvailable()));
    }
}

void FileDownloader::fileDownloaded() {
    if (opened)
        file.close();   // file is now avalaible for caller (fileName)
    emit downloaded();
}

void FileDownloader::cancelDownload() {
    disconnect(reply, SIGNAL(downloadProgress(qint64,qint64)), this, SLOT(showProgress(qint64,qint64)));
    disconnect(reply, SIGNAL(finished()), this, SLOT(fileDownloaded()));
    reply->abort();
    progress->close();
    if (opened)
        file.remove();      // Close and remove
    emit aborted();
}

void FileDownloader::showProgress(qint64 bytesSent, qint64 bytesTotal) {
    progress->setMaximum(bytesTotal);
    progress->setValue(bytesSent);
}

QByteArray FileDownloader::downloadedData() const {
    return m_DownloadedData;
}
