/*
 * SPDX-FileCopyrightText: 2024-2025 Bruno Anselme <be.root@gfree.fr>
 *
 * Authors:
 *   Bruno Anselme <be.root@gfree.fr>
 *
 *   SPDX-License-Identifier: GPL-3.0-or-later
 *
 * This file is part of the NoComprendo software.
*/

#ifndef FILEDOWNLOADER_H
#define FILEDOWNLOADER_H

#include <QObject>
#include <QByteArray>
#include <QNetworkAccessManager>
#include <QNetworkRequest>
#include <QNetworkReply>
#include <QProgressDialog>
#include <QFile>

class FileDownloader : public QObject
{
    Q_OBJECT
public:
    explicit FileDownloader(QUrl url, QString fileName, QObject *parent = 0);
    virtual ~FileDownloader();

    QByteArray          downloadedData() const;
    QString             errorString()       { return reply->errorString(); }
    QNetworkReply::NetworkError error()     { return reply->error(); }

signals:
    void downloaded();
    void aborted();

private slots:
    void fileDownloaded();
    void showProgress(qint64, qint64);
    void cancelDownload();
//    void readDataReady();
    void writeChunk();

private:
    QNetworkAccessManager   m_WebCtrl;
    QByteArray              m_DownloadedData;
    QNetworkReply          *reply;
    QProgressDialog        *progress;
    QString                 fileName;
    QFile                   file;
    bool                    opened;
};

#endif // FILEDOWNLOADER_H
