/*
 * SPDX-FileCopyrightText: 2024-2025 Bruno Anselme <be.root@gfree.fr>
 *
 * Authors:
 *   Bruno Anselme <be.root@gfree.fr>
 *
 *   SPDX-License-Identifier: GPL-3.0-or-later
 *
 * This file is part of the NoComprendo software.
*/

#ifndef MODELLOADER_H
#define MODELLOADER_H

#include <QDialog>
#include <QJsonArray>
#include "config.h"
#include "filedownloader.h"
#include "ui_modelloader.h"

namespace Ui {
class dialogModelLoader;
}

class ModelLoader : public QDialog, private Ui::dialogModelLoader
{
    Q_OBJECT

public:
    explicit ModelLoader();
    ~ModelLoader();

public Q_SLOTS:
    void fillLanguageView();                   //!< Fill tablewidget with available files
    void loadModel(int row, int);
    void loadModel();
    void loadSystemModel()              { systemSpace = true;  loadModel(); }
    void loadUserModel()                { systemSpace = false; loadModel(); }

protected:
    void changeEvent(QEvent *e);

private Q_SLOTS:
    void unzipModel();
    void abortDownload();

private:
    Ui::dialogModelLoader  *ui;
    FileDownloader         *downloader;
    QJsonArray              jsonModels;
    QUrl                    urlModel;
    QString                 fileName;
    QString                 jsonName;
    bool                    systemSpace;
};

#endif // MODELLOADER_H
