/*
 * SPDX-FileCopyrightText: 2024-2025 Bruno Anselme <be.root@gfree.fr>
 *
 * Authors:
 *   Bruno Anselme <be.root@gfree.fr>
 *
 *   SPDX-License-Identifier: GPL-3.0-or-later
 *
 * This file is part of the NoComprendo software.
*/

/**
 * @file      osdeditor.cpp
 * @author    Bruno ANSELME
 * @brief     OSDEditor class definition
 * @details   OSD window editor.
 */

#include <QGuiApplication>
#include <QGraphicsTextItem>
#include <QScreen>
#include <QPainter>
#include "osdeditor.h"
#include "misc.h"

    OSDEditor::OSDEditor() : QDialog()
  , osd()
{
    setWindowFlags(Qt::FramelessWindowHint | Qt::X11BypassWindowManagerHint);
    QRectF rscreens = getDesktopRect();
    setWindowOpacity(0.9);
    setGeometry(rscreens.toRect());
    QLabel  *lbl = new QLabel(tr("Resize and move OSD window.\nEscape or double-click background to quit."));
    lbl->setParent(this);
    lbl->move(100,100);
    QFont font(lbl->font());
    font.setPointSize(16);
    this->setFont(font);
    osd.setFixedHeight(APPCONF.osdSize.height());
    osd.setFixedWidth(APPCONF.osdSize.width());
    osd.setText(tr("On Screen Display"));
    osd.setFrameShape(QFrame::Box);
    osd.setWindowFlags(Qt::Widget);
    osd.setParent(this);
}

void OSDEditor::mouseDoubleClickEvent(QMouseEvent *) {
    emit accepted();
    close();
}
