/*
 * SPDX-FileCopyrightText: 2024-2025 Bruno Anselme <be.root@gfree.fr>
 *
 * Authors:
 *   Bruno Anselme <be.root@gfree.fr>
 *
 *   SPDX-License-Identifier: GPL-3.0-or-later
 *
 * This file is part of the NoComprendo software.
*/

#ifndef SETTAB_H
#define SETTAB_H

#include <QWidget>
#include <QMouseEvent>
#include <QTabWidget>

#include "config.h"
#include "comprendo.h"

namespace Ui {
class SetTab;
}

class SetTab : public QWidget
{
    Q_OBJECT

public:
    explicit SetTab(Comprendo *what_, QString &tabName_, QTabWidget *parent);
    ~SetTab();

Q_SIGNALS:
    void setListening(bool);

protected:
    void        changeEvent(QEvent *);

private Q_SLOTS:
    void        addCommand();
    void        removeCommand();
    void        copyCommand();
    void        pasteCommand();
    void        editionCommand(int row, int column);
    void        editionCommand();
    void        exportSet();
    void        ShowContextMenu(const QPoint& pos);
    void        saveCommandSet(bool reload = false); //!< Save commands set

private:
    void        loadCommandSet();                   //!< Load commands set
    void        addField(int col, QString s);       //!< Add field into (current row, col)
    void        lineToCommand(QString &line);       //!< Convert line (serialized command) into a new row in the table
    QString     commandToLine(int row);             //!< Convert a row in the table into a serialized string

private:
    Ui::SetTab *ui;
    QString     cmdFile;
    QString     tabName;
    int         comCount;
    bool        newcom;
    Comprendo  *what;
};

#endif // SETTAB_H
